stalker.core.models.Link
========================

.. inheritance-diagram::
     stalker.core.models.Link
     :parts: 1

.. currentmodule:: stalker.core.models

.. autoclass:: Link
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Link.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Link.code
      ~Link.created_by
      ~Link.date_created
      ~Link.date_updated
      ~Link.description
      ~Link.filename
      ~Link.name
      ~Link.nice_name
      ~Link.notes
      ~Link.path
      ~Link.tags
      ~Link.type
      ~Link.updated_by
   
   